%function [G p] = MCMC_NetInf( data,pert,b,indegree,initgraph)
function [P] = GibbsNetInfIsing( data,pert,varindex,initgraph,no_it)
%Inferes network structures from given data based on our Bayesian non
%parametric approach.
%
%============================================================
%Input parameter description:
%
%data=data vector, a column represents a perturbation experiment
%
%pert= binary matrix, columns indicate which node is perturbed
%
%b=hyper parameter for the inverse gamma distribution, b=1 is usually a
%good enough assignment.
%
%indegree=The maximum allowed indegree of the network topology. This
%variable depends on the number of perturbation experiments. (indegree< No.
%of perturbation experiments) to make the system of linear equations an
%overdetermined system.
%
%initgraph=The initial adjacency matrix. Use the function 
%createInitialMatrix1(size,indegree) provided with this package.
%Usually a random adjacency matrixsuffices. 
%However careful selection of initial matrix from prior information may
%enhance the performance.
%
%=================================================================
%
%Output parameters:
%
% G=The adjacency matrix of the infered network

G=initgraph;
%G=createInitialGraph1(10,indegree);

%figure; hold on;

P=zeros(size(G));

parfor i=1:length(G)
    P(i,:)=sampleIsing(G,i,data,pert,varindex,no_it,no_it/2); 
end

end

